

** The data for this example are stored as summary statistics in jobsat.dta
use jobsat

** We can learn about the variables
ssd describe

** We can also look at their summary statistics
ssd list

** As an example, we can fit a model where strain mediates the effect of negative affectivity on job satisfaction
sem (satisfaction <- strain na) (strain <- na)

** We can obtain direct, indirect, and total effects and their standard errors using estat teffects
estat teffects

** We can replay the model with standardized coefficients using
sem, standardized

** We can also obtain standardized indirect and total effects
estat teffects, standardized nodirect

** We can also obtain variance decomposition and R-squared for each of the endogenous variables in the model
estat eqgof

** To obtain a Wald test for the null hypothesis that all coefficients in an equation are 0 we can use
estat eqtest


** Let's open the data and take a look at these variables
use hsdata
codebook general paragraph sentence wordc wordm

** The \stliteral{sem} command to fit the model is
sem (Verbal -> general paragraph sentence wordc wordm)

** We can examine the fit of this model using
estat gof, stats(all)

** We can replay the model to obtain standardized coefficients
sem, standardized

** We can fit this model using
sem (Spatial -> visual cubes paper) ///
    (Verbal -> paragraph sentence wordc)

** We can examine model fit using
estat gof, stats(all)

** To obtain modification indices for our model we can type
estat mindices 

** In this case we use var(e.paragraph*e.wordc)
sem (Spatial -> visual cubes paper) ///
    (Verbal -> paragraph sentence wordc), ///
    var(e.paragraph*e.wordc)

** The data for this set of examples come from Wheaton et al. (1977)
use wheaton
ssd describe

** Fit the model
sem (Alien67 -> anomia67 pwless67) /// 
    (Alien71 -> anomia71 pwless71) ///
    (SES -> educ66 occstat66) ///
    (Alien67 <- SES) ///
    (Alien71 <- Alien67 SES)

** We'll start by storing the estimates from the model we have already run
estimates store nocov

** Now we can run the model with the covariances added
sem (Alien67 -> anomia67 pwless67) ///
    (Alien71 -> anomia71 pwless71) ///
    (SES -> educ66 occstat66) ///
    (Alien67 <- SES) ///
    (Alien71 <- Alien67 SES), ///
        cov(e.anomia67*e.anomia71 ///
           e.pwless67*e.pwless71)

** First we store the estimates
estimates store withcov

** Then we can run the likelihood ratio test
lrtest nocov withcov

** To demonstrate we will return to the two-factor CFA model we fit earlier
use hsdata, clear

** The students in this dataset come from two different schools
tab school

** Our command is
sem (Spatial -> visual cubes paper) ///
    (Verbal -> paragraph sentence wordc), ///
    mean(Spatial@0 Verbal@0) ///
    group(school) ginvariant(none) 

** Let's give it a try
estat ginvariant

** Let's begin by opening the dataset and looking at the items q1-q8
use math
codebook q1-q8

** []
gsem (MathAb -> q1-q8, logit), nodvheader

** Let's look more closely at these items
codebook att*

** We will use the ologit option to model the responses att1-att5 using an ordered logistic model
gsem (MathAb -> q1-q8, logit) ///
     (MathAtt -> att1-att5, ologit) ///
     (MathAtt -> MathAb), nodvheader

** This time we will measure the latent variable MathAb using test scores, let's take a look
codebook school test*

** Run the model
gsem (MathAb SchQual[school] -> test1 test2 test3 test4)
